#
# spec file for package frei0r-plugins
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           frei0r-plugins
Version:        1.8.0
Release:        2.4
Summary:        Collection of video sources and filters plugins
# Upstream says 2.0+ but quite few of their plugins are GPL-3.0+
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://frei0r.dyne.org/
Source0:        https://files.dyne.org/frei0r/releases/frei0r-plugins-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo) >= 1.0.0
BuildRequires:  pkgconfig(gavl) >= 0.2.3
%if 0%{suse_version} == 1500 && 0%{?sle_version} < 150400
BuildRequires:  pkgconfig(opencv)
%else
BuildRequires:  pkgconfig(opencv4)
%endif

%description
This package provides a collection of video sources and filters plugins,
using the Frei0r API.

%package opencv
Summary:        OpenCV video sources and filters plugins
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name} = %{version}-%{release}

%description opencv
These plugins may cause slow exports due to multiprocessing issues
in kdenlive and shotcut. plugins facebl0r and facedetect.
See boo#1068792

%package devel
Summary:        Frei0r plugin API for video sources and filters
Group:          Development/Libraries/C and C++

%description devel
Frei0r is a minimalistic plugin API for video sources and filters. The
behaviour of the effects can be controlled from the host by simple
parameters. The intent is to solve the recurring reimplementation or
adaptation issue of standard effects.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%license COPYING.txt
%doc AUTHORS.txt ChangeLog.txt README.txt
%{_libdir}/frei0r-1/
%exclude %{_libdir}/frei0r-1/facebl0r.so
%exclude %{_libdir}/frei0r-1/facedetect.so

%files opencv
%license COPYING.txt
%dir %{_libdir}/frei0r-1
%{_libdir}/frei0r-1/facebl0r.so
%{_libdir}/frei0r-1/facedetect.so

%files devel
%{_libdir}/pkgconfig/frei0r.pc
%{_includedir}/frei0r.h

%changelog
* Mon Sep 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Use opencv 4 for building frei0r-plugins when possible.
  opencv 3 doesn't support FFmpeg 5.
* Mon May  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.8.0
  * Consolidated opencv4 support
  * spelling fixes
  * using the void keyword in function declaration
  * Add FX aech0r . Aim to simulate an analog video echo.
  * Fix build for opencv4
  * Fill uninitialized gaps between grid images
  * Avoid destructing alpha channel.
  * pixeliz0r: Limit the blocksize to a minimum of 1 pixel
  * edgeglow: Fix hsl to rgb conversion
- Drop 0001-Port-facebl0r-to-OpenCV-C-API.patch, merged upstream
* Wed Jan  1 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.7.0
  * This release includes three new filters, code cleanups and several
    bugfixes improving stability of existing plugins.
  * New filters (3): normaliz0r, elastic_scale, premultiply.
  * Updated (47): alpha0ps, baltan, bgsubtractor, bluescreen0r, blur,
    c0rners, cairogradient, cairoimagegrid, cartoon, cluster,
    coloradj, colorhalftone, curves, d90stairsteppingfix, defish0r,
    delay0r, edgeglow, emboss, facebl0r, facedetect, levels,
    lightgraffiti, measure, ndvi, nervous, nosync0r, primaries,
    rgbnoice, rgbsplit0r, scanline0r, select0r, sopsat, spillsupress,
    three_point_balance, timeout, tutorial, vertigo, vignette, water,
    alphaatop, alphain, alphaout, alphaover, alphaxor,
    cairoaffineblend, cairoblend, xfade0r
- Drop obsolete patches:
  * frei0r-plugins-1.4-missing_include.patch
  * frei0r-plugins-openCV-3.0-compatibility.patch
  * frei0r-plugins-openCV-3.4.2-compatibility.patch
- Fix compilation with OpenCV 3.4.9/4.2.0
  * 0001-Port-facebl0r-to-OpenCV-C-API.patch
* Wed Oct 31 2018 Christophe Giboudeaux <christophe@krop.fr>
- Add frei0r-plugins-openCV-3.4.2-compatibility.patch to fix a
  build failure with openCV > 3.4.1
- Run spec-cleaner
* Sat Dec  9 2017 davejplater@gmail.com
- Split off plugins built against OpenCV because they cause
  multiprocessing issues in shotcut and kdenlive. See boo#1068792
  and https://github.com/mltframework/mlt/issues/274.
* Wed Dec  6 2017 tchvatal@suse.com
- Reduce bit operations we do in the spec and convert to pkgconfig
  dependencies
- Switch LICENSE to GPL-3.0+ even tho upstream says 2.0+ is enough
  quite few filters and generators are 3.0+ only
* Tue Nov 28 2017 davejplater@gmail.com
- Update to version 1.6.1
- Rebase frei0r-plugins-1.4-missing_include.patch
- Rebase frei0r-plugins-openCV-3.0-compatibility.patch it is mostly
  included upstream.
- Upstream changes:
  * Minor fixes to the build system. Version correctly updated.
  * This release contains new filters and some bugfixes to parameters
  and building environment, documentation is updated accordingly.
  * New filters (3): bgsubtract0r, glitch0r, rgbsplit0r
  * Updated (2): Distort0r now mode and velocity, Curves has improved
  precision.
  * This release fixes several major bugs in existing plugins and adds
  one new filter: NDVI (Normalized Difference Vegetation Index).
* Fri Mar  4 2016 olaf@aepfle.de
- Fix frei0r-plugins-openCV-3.0-compatibility.patch
* Fri Mar  4 2016 zaitor@opensuse.org
- Update Url to http://frei0r.dyne.org/, show that we are using the
  fork and not the original frei0r.
* Thu Mar  3 2016 tittiatcoke@gmail.com
- Add frei0r-plugins-openCV-3.0-compatibility.patch: fix the
  compilation against OpenCV 3. This patch is based on the two
  upstream commits 129eea and 7ed3f84e6.
* Thu Nov 12 2015 ecsos@opensuse.org
- change if clause for opencv-qt5-devel, so no need for
  ProjectConfig
* Thu Nov  5 2015 wbauer@tmo.at
- Build against opencv-qt5-devel on Leap as well, Leap comes with
  the KF5/Qt5 based kdenlive (boo#930616)
* Sat May 16 2015 wbauer@tmo.at
- Build against opencv-qt5-devel on > 13.2, otherwise it would
  crash kdenlive/libmlt which are built against Qt5
* Wed Mar  6 2013 reddwarf@opensuse.org
- Update to version 1.4:
  * Fix several major bugs in existing plugins
  * Add new filters and the optional dependency to cairo.
  - New filters (18): IIRblur, Vignette, Keyspillm0pup, Timeout,
    Posterize, Dither, Spillsupress, Emboss, Colgate, RGBNoise,
    Colorize, Softglow, ColrHalftone, Sigmoidaltransfer,
    Colortap, cairogradient, cairoimagegrid, medians
  - New mixers: cairoblend, cairoaffineblend
- Remove frei0r-missing-return.patch and frei0r-plugins-compiler-warnings.patch
- Add frei0r-plugins-1.4-missing_include.patch
- Add pkgconfig(cairo) BuildRequires
* Wed Oct  5 2011 dimstar@opensuse.org
- Add pkgconfig(gavl) BuildRequires to enable the remaining
  filters: rgbparade, scale0tilt, vectorscope.
- Add frei0r-plugins-compiler-warnings.patch: Fix compiler warning
  on undefined operation. Patch taken from upstream git, commit
  id 8f8090.
* Wed Sep 28 2011 vuntz@opensuse.org
- Cleanup package.
* Sat Sep  3 2011 dimstar@opensuse.org
- Initial package, version 1.3.
